@@ -11,6 +11,7 @@ import pickle
 # ======================
 #
 
+
 def makedirs(filepath):
     os.makedirs(os.path.dirname(filepath), exist_ok=True)
 
@@ -23,26 +24,26 @@ def walk(source_dir):
     return paths
 
 
-def loadJSON(filepath, encoding="utf-8"):
+def load_json(filepath, encoding="utf-8"):
     return json.load(open(filepath, "r", encoding=encoding))
 
 
-def dumpJSON(obj, filepath, indent=None, ensure_ascii=False, makedir=True):
+def dump_json(obj, filepath, indent=None, ensure_ascii=False, makedir=True):
     if makedir:
-        makedirs(filepath)    
+        makedirs(filepath)
     json.dump(
-        obj, 
-        open(filepath, "w"), 
-        indent=indent, 
+        obj,
+        open(filepath, "w"),
+        indent=indent,
         ensure_ascii=ensure_ascii
     )
 
 
-def loadPickle(filepath):
+def load_pickle(filepath):
     return pickle.load(open(filepath, "rb"))
 
 
-def dumpPickle(obj, filepath, makedir=True):
+def dump_pickle(obj, filepath, makedir=True):
     if makedir:
         makedirs(filepath)
     pickle.dump(obj, open(filepath, "wb"))
